
import java.io.*;
import java.sql.*;
import java.util.*;

public class ConnFactory {
	private static int maxconn = 0;
	private static String url = null;
	private static String driver = null;
	private static String user = null;
	private static String password = null;
	private static ConnFactory connFactory;
	
	static{
		try{
			loadProperties("jdbc.properties");			
		}catch(IOException e){
			System.out.println("jdbc.properties load fail...");
			e.printStackTrace();			
		}
	}
	
	private ConnFactory(){};
		
	public static ConnFactory getDefaultFactory(){
		if(connFactory == null){
			connFactory = new ConnFactory();
		}
		return connFactory;
	}
	
	public Connection createConnection() throws SQLException, ClassNotFoundException{
		Class.forName(driver);
		Connection conn = DriverManager.getConnection(url, user, password);
		return conn;
	}
	
	public static void loadProperties(String filename) throws IOException{
		Properties p = new Properties();
		FileInputStream in = new FileInputStream(filename);
		p.load(in);
		in.close();
		url = p.getProperty("url");
		driver = p.getProperty("driver");
		user = p.getProperty("user");
		password = p.getProperty("password");
		maxconn = Integer.parseInt(p.getProperty("maxconn"));
	}
	
	public static int getMaxConn(){
		return maxconn;
	}
}
