

import java.sql.*;
import java.util.*;

public class ConnPool {
	private Vector buffer = new Vector();
	private static ConnPool connPool;
	
	static{
		try{
			initConnPool();
		}catch(SQLException e){
			System.out.println("Connection Create Error");
			e.printStackTrace();
		}catch(ClassNotFoundException e2){
			System.out.println("Driver Class Not Found Error");
			e2.printStackTrace();
		}
	}
	
	private ConnPool(){}
	
	public static void initConnPool() throws SQLException, ClassNotFoundException{
		destroyConnPool();
		Vector temp = ConnPool.getConnPool().getConnPoolBuffer();
		ConnFactory factory = ConnFactory.getDefaultFactory();
		for(int i = 0; i<factory.getMaxConn(); i++){
			Connection conn = factory.createConnection();
			temp.addElement(conn);
			System.out.println("New Connection Created.." + conn);
		}
	}
	
	public synchronized static void destroyConnPool(){
		Vector temp = ConnPool.getConnPool().getConnPoolBuffer();
		Enumeration enu = temp.elements();
		while(enu.hasMoreElements()){
			Connection conn = (Connection)enu.nextElement();
			if(conn != null){
				try{
					conn.close();
					System.out.println("Connection Closed.." + conn);
				}catch(SQLException e){
					e.printStackTrace();
				}
			}
		}
	}
		
	public static ConnPool getConnPool(){
		if(connPool == null){
			connPool = new ConnPool();
		}
		return connPool;
	}
	
	public synchronized Connection getConnection() throws InterruptedException{
		while(buffer.size() == 0){
			this.wait();
		}
		Connection conn = (Connection)this.buffer.remove(buffer.size()-1);
		System.out.println("getConnection() " + conn);
		return conn;
	}
	
	public synchronized void releaseConnection(Connection conn){
		this.buffer.addElement(conn);
		System.out.println("releaseConnection() " + conn);
		this.notifyAll();
	}
	
	private Vector getConnPoolBuffer(){
		return this.buffer;
	}
}
